@@ -29,7 +29,7 @@ from fabric.api import *
 from time import gmtime, strftime
 import os
 import sys
-#from git import Repo
+from git import Repo
 import distutils.sysconfig
 from instanceinfo import InstanceInfo
 
@@ -309,7 +309,7 @@ def build(branch='', ngBuild='', ngApp='', angularBuild='', angularEnv='', angul
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
             local('yarn build %s %s' % (options, ngApp))
-            local('cp {package.json,yarn.lock,knexfile.js} dist/')
+            local('cp {package.json,yarn.lock,knexfile.js, requirements.txt} dist/')
             local('cp -R migrations/ dist')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
 
@@ -351,7 +351,7 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
             local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/api/config/application-%s.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
-            local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
+    	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
     if buildScheduler in TRUTH_VALUES:
         local('mkdir -p deploy/scheduler-worker/config')
@@ -378,8 +378,8 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
         local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
         if prodSecrets in TRUTH_VALUES:
             local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
-            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
-            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
             local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
@@ -514,11 +514,11 @@ def remote_inflate_code(numKeep='5'):
 
 @task
 def codeversioner():
-#    repo = Repo('.')
+    repo = Repo('.')
     headcommit = repo.head.commit
     commitid = headcommit.hexsha
     versionhash = commitid
-    print (versionhash)
+    print versionhash
     with cd('/data/deploy/pending'):
         run("echo 'version=\"%s\"' > /tmp/versioner.py" % versionhash)
         cmd = 'cp /tmp/versioner.py /data/deploy/pending/versioner.py'
@@ -660,7 +660,7 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
         run('tar zxf %s.tar.gz -C %s' % (TAR_NAME, APP_UTILS_DIR))
 
     # run the "instanceType"-command.sh in the appropriate branch
-    cmdToRun = "sudo /home/ubuntu/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
+    cmdToRun = "sudo --preserve-env=HOME /home/ubuntu/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
     run(cmdToRun)
 
     # run deployenv on the instance to get the new values into /etc/enviornmnet
@@ -722,14 +722,14 @@ def restart_web(doCollectStatic=None,nginxOnly=False):
 
 @task
 @parallel
-def reload_worker(asyncF="djangorq", doCollectStatic=None):
+def reload_worker(async="djangorq", doCollectStatic=None):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
 
-    if asyncF == "djangorq":
+    if async == "djangorq":
         reload_djangorq()
-    elif asyncF == "celery":
+    elif async == "celery":
         restart_celery()
     else:
         logger.info("Specified async facility not supported")
@@ -737,14 +737,14 @@ def reload_worker(asyncF="djangorq", doCollectStatic=None):
 
 @task
 @parallel
-def restart_worker(asyncF="djangorq", doCollectStatic=None):
+def restart_worker(async="djangorq", doCollectStatic=None):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
 
-    if asyncF == "djangorq":
+    if async == "djangorq":
         restart_djangorq()
-    elif asyncF == "celery":
+    elif async == "celery":
         restart_celery()
     else:
         logger.info("Specified async facility not supported")
